@@ -49,7 +49,7 @@ class LJ_Import {
 
 			preg_match('|<eventtime>(.*?)</eventtime>|is', $post, $post_date);
 			$post_date = strtotime($post_date[1]);
-			$post_date = gmdate('Y-m-d H:i:s', $post_date);
+			$post_date = date('Y-m-d H:i:s', $post_date);
 
 			preg_match('|<event>(.*?)</event>|is', $post, $post_content);
 			$post_content = str_replace(array ('<![CDATA[', ']]>'), '', trim($post_content[1]));
@@ -66,11 +66,13 @@ class LJ_Import {
 
 			echo '<li>';
 			if ($post_id = post_exists($post_title, $post_content, $post_date)) {
-				printf(__('Post <i>%s</i> already exists.'), stripslashes($post_title));
+				printf(__('Post <em>%s</em> already exists.'), stripslashes($post_title));
 			} else {
-				printf(__('Importing post <i>%s</i>...'), stripslashes($post_title));
+				printf(__('Importing post <em>%s</em>...'), stripslashes($post_title));
 				$postdata = compact('post_author', 'post_date', 'post_content', 'post_title', 'post_status');
 				$post_id = wp_insert_post($postdata);
+				if ( is_wp_error( $post_id ) )
+					return $post_id;
 				if (!$post_id) {
 					_e("Couldn't get post ID");
 					echo '</li>';
@@ -117,7 +119,7 @@ class LJ_Import {
 			}
 			if ( $num_comments ) {
 				echo ' ';
-				printf(__('(%s comments)'), $num_comments);
+				printf(__ngettext('(%s comment)', '(%s comments)', $num_comments), $num_comments);
 			}
 			echo '</li>';
 		}
@@ -132,8 +134,11 @@ class LJ_Import {
 		}
 
 		$this->file = $file['file'];
-		$this->import_posts();
+		$result = $this->import_posts();
+		if ( is_wp_error( $result ) )
+			return $result;
 		wp_import_cleanup($file['id']);
+		do_action('import_done', 'livejournal');
 
 		echo '<h3>';
 		printf(__('All done. <a href="%s">Have fun!</a>'), get_option('home'));
@@ -154,7 +159,9 @@ class LJ_Import {
 				break;
 			case 1 :
 				check_admin_referer('import-upload');
-				$this->import();
+				$result = $this->import();
+				if ( is_wp_error( $result ) )
+					echo $result->get_error_message();
 				break;
 		}
 
@@ -168,5 +175,5 @@ class LJ_Import {
 
 $livejournal_import = new LJ_Import();
 
-register_importer('livejournal', __('LiveJournal'), __('Import posts from a LiveJournal XML export file'), array ($livejournal_import, 'dispatch'));
+register_importer('livejournal', __('LiveJournal'), __('Import posts from a LiveJournal XML export file.'), array ($livejournal_import, 'dispatch'));
 ?>
