@@ -30,19 +30,19 @@ switch ($step) {
 <input type="hidden" name="step" value="1" />
 <input type="hidden" name="MAX_FILE_SIZE" value="30000" />
 <div style="width: 48%;" class="alignleft">
-<h3><?php _e('Specify an OPML URL:'); ?></h3>
-<input type="text" name="opml_url" size="50" style="width: 90%;" value="http://" />
+<h3><label for="opml_url"><?php _e('Specify an OPML URL:'); ?></label></h3>
+<input type="text" name="opml_url" id="opml_url" size="50" style="width: 90%;" value="http://" />
 </div>
 
 <div style="width: 48%;" class="alignleft">
-<h3><?php _e('Or choose from your local disk:'); ?></h3>
+<h3><label for="userfile"><?php _e('Or choose from your local disk:'); ?></label></h3>
 <input id="userfile" name="userfile" type="file" size="30" />
 </div>
 
 </div>
 
-<p style="clear: both; margin-top: 1em;"><?php _e('Now select a category you want to put these links in.') ?><br />
-<?php _e('Category:') ?> <select name="cat_id">
+<p style="clear: both; margin-top: 1em;"><label for="cat_id"><?php _e('Now select a category you want to put these links in.') ?></label><br />
+<?php _e('Category:') ?> <select name="cat_id" id="cat_id">
 <?php
 $categories = get_terms('link_category', 'get=all');
 foreach ($categories as $category) {
